aboutsummaryrefslogtreecommitdiffstats
path: root/poi
diff options
context:
space:
mode:
Diffstat (limited to 'poi')
-rw-r--r--poi/src/main/java/org/apache/poi/ss/util/SheetUtil.java14
1 files changed, 11 insertions, 3 deletions
diff --git a/poi/src/main/java/org/apache/poi/ss/util/SheetUtil.java b/poi/src/main/java/org/apache/poi/ss/util/SheetUtil.java
index f90d229895..a6ea07893a 100644
--- a/poi/src/main/java/org/apache/poi/ss/util/SheetUtil.java
+++ b/poi/src/main/java/org/apache/poi/ss/util/SheetUtil.java
@@ -100,10 +100,10 @@ public class SheetUtil {
/**
* A system property which can be enabled to not fail when the
* font-system is not available on the current machine
*/
- private static boolean ignoreMissingFontSystem =
- Boolean.parseBoolean(System.getProperty("org.apache.poi.ss.ignoreMissingFontSystem"));
+ private static boolean ignoreMissingFontSystem = initIgnoreMissingFontSystemFlag();
/**
* Which default char-width to use if the font-system is unavailable.
@@ -507,4 +507,12 @@ public class SheetUtil {
protected static void setFontRenderContext(FontRenderContext fontRenderContext) {
SheetUtil.fontRenderContext = fontRenderContext;
}
+
+ private static boolean initIgnoreMissingFontSystemFlag() {
+ final String flag = System.getProperty("org.apache.poi.ss.ignoreMissingFontSystem");
+ if (flag != null) {
+ return !flag.trim().equalsIgnoreCase("false");
+ }
+ return true;
+ }
}
@@ -100,10 +100,10 @@ public class SheetUtil {
/**
* A system property which can be enabled to not fail when the
- * font-system is not available on the current machine
+ * font-system is not available on the current machine.
+ * Since POI 5.3.1, this flag is enabled by default.
*/